"""
    NSE indices symbol map
"""
symbol_map = [
    {
        "keys": ["NIFTY 50", "NIFTY50", "NIFTY"],
        "indices": "NIFTY 50",
        "derivatives": "NIFTY",
    },
    {
        "keys": ["NIFTY BANK", "NIFTYBANK", "BANKNIFTY"],
        "derivatives": "BANKNIFTY",
        "indices": "NIFTY BANK",
    },
    {
        "keys": ["NIFTY FINANCIAL SERVICES", "FINNIFTY", "NIFTY FIN SERVICE"],
        "derivatives": "FINNIFTY",
        "indices": "NIFTY FINANCIAL SERVICES",
    },
    {"keys": ["NIFTY NEXT 50"], "derivatives": "", "indices": "NIFTY NEXT 50"},
    {"keys": ["NIFTY MIDCAP 50"], "derivatives": "", "indices": "NIFTY MIDCAP 50"},
    {"keys": ["NIFTY MIDCAP 100"], "derivatives": "", "indices": "NIFTY MIDCAP 100"},
    {"keys": ["NIFTY MIDCAP 150"], "derivatives": "", "indices": "NIFTY MIDCAP 150"},
    {"keys": ["NIFTY SMALLCAP 50"], "derivatives": "", "indices": "NIFTY SMALLCAP 50"},
    {
        "keys": ["NIFTY SMALLCAP 100"],
        "derivatives": "",
        "indices": "NIFTY SMALLCAP 100",
    },
    {
        "keys": ["NIFTY SMALLCAP 250"],
        "derivatives": "",
        "indices": "NIFTY SMALLCAP 250",
    },
    {
        "keys": ["NIFTY MIDSMALLCAP 400"],
        "derivatives": "",
        "indices": "NIFTY MIDSMALLCAP 400",
    },
    {"keys": ["NIFTY 100"], "derivatives": "", "indices": "NIFTY 100"},
    {"keys": ["NIFTY 200"], "derivatives": "", "indices": "NIFTY 200"},
    {
        "keys": ["NIFTY500 MULTICAP 50:25:25"],
        "derivatives": "",
        "indices": "NIFTY500 MULTICAP 50:25:25",
    },
    {
        "keys": ["NIFTY LARGEMIDCAP 250"],
        "derivatives": "",
        "indices": "NIFTY LARGEMIDCAP 250",
    },
    {
        "keys": ["NIFTY MIDCAP SELECT"],
        "derivatives": "",
        "indices": "NIFTY MIDCAP SELECT",
    },
    {
        "keys": ["NIFTY TOTAL MARKET"],
        "derivatives": "",
        "indices": "NIFTY TOTAL MARKET",
    },
    {
        "keys": ["NIFTY MICROCAP 250"],
        "derivatives": "",
        "indices": "NIFTY MICROCAP 250",
    },
    {"keys": ["NIFTY AUTO"], "derivatives": "", "indices": "NIFTY AUTO"},
    {"keys": ["NIFTY ENERGY"], "derivatives": "", "indices": "NIFTY ENERGY"},
    {
        "keys": ["NIFTY FINANCIAL SERVICES 25/50"],
        "derivatives": "",
        "indices": "NIFTY FINANCIAL SERVICES 25/50",
    },
    {"keys": ["NIFTY FMCG"], "derivatives": "", "indices": "NIFTY FMCG"},
    {"keys": ["NIFTY IT"], "derivatives": "", "indices": "NIFTY IT"},
    {"keys": ["NIFTY MEDIA"], "derivatives": "", "indices": "NIFTY MEDIA"},
    {"keys": ["NIFTY METAL"], "derivatives": "", "indices": "NIFTY METAL"},
    {"keys": ["NIFTY PHARMA"], "derivatives": "", "indices": "NIFTY PHARMA"},
    {"keys": ["NIFTY PSU BANK"], "derivatives": "", "indices": "NIFTY PSU BANK"},
    {"keys": ["NIFTY REALTY"], "derivatives": "", "indices": "NIFTY REALTY"},
    {
        "keys": ["NIFTY PRIVATE BANK"],
        "derivatives": "",
        "indices": "NIFTY PRIVATE BANK",
    },
    {
        "keys": ["NIFTY HEALTHCARE INDEX"],
        "derivatives": "",
        "indices": "NIFTY HEALTHCARE INDEX",
    },
    {
        "keys": ["NIFTY CONSUMER DURABLES"],
        "derivatives": "",
        "indices": "NIFTY CONSUMER DURABLES",
    },
    {
        "keys": ["NIFTY OIL &amp; GAS"],
        "derivatives": "",
        "indices": "NIFTY OIL &amp; GAS",
    },
    {
        "keys": ["NIFTY DIVIDEND OPPORTUNITIES 50"],
        "derivatives": "",
        "indices": "NIFTY DIVIDEND OPPORTUNITIES 50",
    },
    {"keys": ["NIFTY50 VALUE 20"], "derivatives": "", "indices": "NIFTY50 VALUE 20"},
    {
        "keys": ["NIFTY100 QUALITY 30"],
        "derivatives": "",
        "indices": "NIFTY100 QUALITY 30",
    },
    {
        "keys": ["NIFTY50 EQUAL WEIGHT"],
        "derivatives": "",
        "indices": "NIFTY50 EQUAL WEIGHT",
    },
    {
        "keys": ["NIFTY100 EQUAL WEIGHT"],
        "derivatives": "",
        "indices": "NIFTY100 EQUAL WEIGHT",
    },
    {
        "keys": ["NIFTY100 LOW VOLATILITY 30"],
        "derivatives": "",
        "indices": "NIFTY100 LOW VOLATILITY 30",
    },
    {"keys": ["NIFTY ALPHA 50"], "derivatives": "", "indices": "NIFTY ALPHA 50"},
    {
        "keys": ["NIFTY200 QUALITY 30"],
        "derivatives": "",
        "indices": "NIFTY200 QUALITY 30",
    },
    {
        "keys": ["NIFTY ALPHA LOW-VOLATILITY 30"],
        "derivatives": "",
        "indices": "NIFTY ALPHA LOW-VOLATILITY 30",
    },
    {
        "keys": ["NIFTY200 MOMENTUM 30"],
        "derivatives": "",
        "indices": "NIFTY200 MOMENTUM 30",
    },
    {
        "keys": ["NIFTY MIDCAP150 QUALITY 50"],
        "derivatives": "",
        "indices": "NIFTY MIDCAP150 QUALITY 50",
    },
    {"keys": ["NIFTY COMMODITIES"], "derivatives": "", "indices": "NIFTY COMMODITIES"},
    {
        "keys": ["NIFTY INDIA CONSUMPTION"],
        "derivatives": "",
        "indices": "NIFTY INDIA CONSUMPTION",
    },
    {"keys": ["NIFTY CPSE"], "derivatives": "", "indices": "NIFTY CPSE"},
    {
        "keys": ["NIFTY INFRASTRUCTURE"],
        "derivatives": "",
        "indices": "NIFTY INFRASTRUCTURE",
    },
    {"keys": ["NIFTY MNC"], "derivatives": "", "indices": "NIFTY MNC"},
    {
        "keys": ["NIFTY GROWTH SECTORS 15"],
        "derivatives": "",
        "indices": "NIFTY GROWTH SECTORS 15",
    },
    {"keys": ["NIFTY PSE"], "derivatives": "", "indices": "NIFTY PSE"},
    {
        "keys": ["NIFTY SERVICES SECTOR"],
        "derivatives": "",
        "indices": "NIFTY SERVICES SECTOR",
    },
    {
        "keys": ["NIFTY100 LIQUID 15"],
        "derivatives": "",
        "indices": "NIFTY100 LIQUID 15",
    },
    {
        "keys": ["NIFTY MIDCAP LIQUID 15"],
        "derivatives": "",
        "indices": "NIFTY MIDCAP LIQUID 15",
    },
    {
        "keys": ["NIFTY INDIA DIGITAL"],
        "derivatives": "",
        "indices": "NIFTY INDIA DIGITAL",
    },
    {"keys": ["NIFTY100 ESG"], "derivatives": "", "indices": "NIFTY100 ESG"},
    {
        "keys": ["NIFTY INDIA MANUFACTURING"],
        "derivatives": "",
        "indices": "NIFTY INDIA MANUFACTURING",
    },
]
